@@ -201,7 +201,7 @@ public:
      * @brief setGpuSizeFromDmesg:设置由Dmesg获取的显卡大小信息
      * @param info:由由Dmesg获取的显卡大小信息
      */
-    void setGpuSizeFromDmesg(const QString &info);
+    void setGpuSizeFromDmesg(const QMap<QString, QString> &mapInfo);
 
     // 内存设备相关 *************************************************************************************
     /**
@@ -304,10 +304,16 @@ public:
     void setAudioInfoFromLshw(const QMap<QString, QString> &mapInfo);
 
     /**
-     * @brief setAudioChipFromDmesg:从Dmesg获取的信息设置声卡芯片型号
-     * @param info:声卡芯片型号
+     * @brief setAudioInfoFrom_sysFS:设置由sysFS获取的声卡信息
+     * @param mapInfo:由sysFS获取的声卡信息map
      */
-    void setAudioChipFromDmesg(const QString &info);
+    void setAudioInfoFrom_sysFS(const QMap<QString, QString> &mapInfo);
+
+    // /**
+    //  * @brief setAudioChipFromDmesg:从Dmesg获取的信息设置声卡芯片型号
+    //  * @param info:声卡芯片型号
+    //  */
+     void setAudioChipFromDmesg(const QString &info);
 
     // 网络设备相关
     /**
