@@ -287,9 +287,11 @@ void DeviceGenerator::generatorAudioDevice()
 {
     // 生成音频适配器
     getAudioInfoFromHwinfo();
-    getAudioChipInfoFromDmesg();
+    // getAudioChipInfoFromDmesg();  //将两个设备芯片显示为一个，该功能代码逻辑错误  被 getAudioInfoFrom_sysFS 取代
     getAudioInfoFromLshw();
-    //getAudioInfoFromCatInput();
+    getAudioInfoFrom_sysFS();
+    // getAudioInfoFromCatInput();
+    
 }
 
 void DeviceGenerator::generatorBluetoothDevice()
@@ -613,14 +615,19 @@ void DeviceGenerator::getGpuInfoFromXrandr()
 void DeviceGenerator::getGpuSizeFromDmesg()
 {
     // 加载从dmesg获取的显示适配器信息，设置显存大小
-    const QList<QMap<QString, QString>> &lstMap = DeviceManager::instance()->cmdInfo("dmesg");
+    const QList<QMap<QString, QString> > &lstMap = DeviceManager::instance()->cmdInfo("dmesg");
     if (lstMap.size() > 0 && lstMap[0].size() > 0)
-        DeviceManager::instance()->setGpuSizeFromDmesg(lstMap[0]["Size"]);
+        for (QMap<QString, QString> curMap : lstMap) {
+            DeviceManager::instance()->setGpuSizeFromDmesg(curMap);
+        }
     else {
         // dmesg无法获取显存信息时从nvidia-settings获取
         const QList<QMap<QString, QString>> &nvidiaMap = DeviceManager::instance()->cmdInfo("nvidia");
-        if (nvidiaMap.size() > 0 && nvidiaMap[0].size() > 0)
-            DeviceManager::instance()->setGpuSizeFromDmesg(nvidiaMap[0]["Size"]);
+        if (nvidiaMap.size() > 0 && nvidiaMap[0].size() > 0){
+            for (QMap<QString, QString> curMap : nvidiaMap) {
+                DeviceManager::instance()->setGpuSizeFromDmesg(curMap);
+            }
+        }
     }
 }
 void DeviceGenerator::getMonitorInfoFromHwinfo()
@@ -676,6 +683,33 @@ void DeviceGenerator::getAudioInfoFromHwinfo()
     DeviceManager::instance()->deleteDisableDuplicate_AudioDevice();
 }
 
+void DeviceGenerator::getAudioInfoFrom_sysFS()
+{
+    // 加载从sysFS中获取的音频适配器信息，设备声卡型号
+    // QMap<QString, QString> mapInfo_0;
+    // QMap<QString, QString> mapInfo_1;
+    // QMap<QString, QString> mapInfo_2;
+    QMap<QString, QString> mapInfo;
+    QString path;
+
+    for(int i=0; i<5;i++){
+        mapInfo.clear();
+        DeviceAudio *device = new DeviceAudio();
+        bool getcard = device->setInfoFrom_sysFS(mapInfo,i);
+        if(getcard){
+            path = mapInfo["SysFS ID"];
+            DeviceAudio *tmpdevice = dynamic_cast<DeviceAudio *>(DeviceManager::instance()->getAudioDevice(path));
+            if (!tmpdevice){  // 没有该设备 说加新的
+                DeviceManager::instance()->addAudioDevice(device);
+            } else{  //找到有就 加芯片等信息
+                QString chip = mapInfo["chip"];
+                // DeviceManager::instance()->setAudioChipFromDmesg(chip);
+                tmpdevice->setAudioChipFromDmesg(chip);
+            }
+        }
+    }
+}
+
 void DeviceGenerator::getAudioInfoFromLshw()
 {
     // 加载从lshw中获取的音频适配器信息
@@ -687,6 +721,7 @@ void DeviceGenerator::getAudioInfoFromLshw()
 
         DeviceManager::instance()->setAudioInfoFromLshw(*it);
     }
+     DeviceManager::instance()->deleteDisableDuplicate_AudioDevice();  //bug 150331  禁用显卡音频，重启后音频信息异常增多
 }
 
 void DeviceGenerator::getAudioInfoFromCatInput()
